@@ -21,6 +21,10 @@
 
 #include <unistd.h>
 #include <sys/types.h>
+#if !(defined(_MSC_VER) || defined(__MINGW32__) || defined(_WIN32))
+#include <pwd.h>
+#include <grp.h>
+#endif
 
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
@@ -71,14 +75,13 @@ extern ProcHandle runInteractiveProcess( wchar_t *cmd,
                                          int *pfdStdError,
                                          int flags,
                                          bool useJobObject,
-                                         HANDLE *hJob,
-                                         HANDLE *hIOcpPort );
+                                         HANDLE *hJob );
 
 typedef void(*setterDef)(DWORD, HANDLE);
 typedef HANDLE(*getterDef)(DWORD);
 
 extern int terminateJob( ProcHandle handle );
-extern int waitForJobCompletion( HANDLE hJob, HANDLE ioPort, DWORD timeout, int *pExitCode, setterDef set, getterDef get );
+extern int waitForJobCompletion( HANDLE hJob );
 
 #endif
 
